import { IUnregisterAppOptions, IUnregisterAppResponse } from "./types/appType.js";
/**
 * Used to unregister the app with given `itemId`. See the [REST Documentation](https://developers.arcgis.com/rest/users-groups-and-items/unregister-app.htm) for more information.
 *
 * ```js
 * import { unregisterApp, IUnregisterAppResponse } from '@esri/arcgis-rest-developer-credentials';
 * import { ArcGISIdentityManager } from "@esri/arcgis-rest-request";
 *
 * const authSession: ArcGISIdentityManager = await ArcGISIdentityManager.signIn({
 *   username: "xyz_usrName",
 *   password: "xyz_pw"
 * });
 *
 * unregisterApp({
 *   itemId: "xyz_itemId",
 *   authentication: authSession
 * }).then((unregisteredApp: IUnregisterAppResponse) => {
 *   // => {itemId: "xyz_itemId", success: true}
 * }).catch(e => {
 *   // => an exception object
 * });
 * ```
 *
 * @param requestOptions - Options for {@linkcode unregisterApp | unregisterApp()}, including `itemId` of which app to be un-registered and an {@linkcode ArcGISIdentityManager} authentication session.
 * @returns A Promise that will resolve to an {@linkcode IUnregisterAppResponse} object representing un-registration status.
 */
export declare function unregisterApp(requestOptions: IUnregisterAppOptions): Promise<IUnregisterAppResponse>;
